EmanuelConvection
--------------------

.. inheritance-diagram:: climlab.convection.EmanuelConvection
   :parts: 1
   :private-bases:

.. automodule:: climlab.convection.emanuel_convection
    :members:
    :undoc-members:
    :show-inheritance:
